@@ -60,6 +60,10 @@ When set to true, the tex output will obey bcor and twoside/oneside.
 An hashref with the options to pass to the templates. It's returned as
 an hash, not as a reference, to protect it from mangling.
 
+=item webfonts
+
+The L<Text::Amuse::Compile::Webfonts> object (or undef).
+
 =back
 
 =head1 INTERNALS
@@ -180,6 +184,10 @@ sub logger {
     return shift->{logger};
 }
 
+sub webfonts {
+    return shift->{webfonts};
+}
+
 sub document {
     my $self = shift;
     # prevent parsing of deleted, bad file
@@ -530,7 +538,9 @@ sub epub {
     my $epub = EBook::EPUB->new;
 
     # embedded CSS
-    $epub->add_stylesheet("stylesheet.css" => $self->_render_css(epub => 1));
+    my $css = $self->_render_css(epub => 1,
+                                 webfonts => $self->webfonts );
+    $epub->add_stylesheet("stylesheet.css" => $css);
 
     # build the title page and some metadata
     my $header = $text->header_as_html;
@@ -643,6 +653,14 @@ sub epub {
         }
         $epub->copy_file($att, $att, $mime);
     }
+    if (my $fonts = $self->webfonts) {
+        foreach my $style (qw/regular italic bold bolditalic/) {
+            $epub->copy_file(File::Spec->catfile($fonts->{srcdir},
+                                                 $fonts->{$style}),
+                             $fonts->{$style},
+                             $fonts->{mimetype});
+        }
+    }
 
     # finish
     $epub->pack_zip($epubname);
@@ -836,7 +854,7 @@ sub _prepare_tex_tokens {
             $parsed{papersize} = $1;
         }
         else {
-            warn "Unrecognized paper size $size, usign the default\n";
+            warn "Unrecognized paper size $size, using the default\n";
         }
     }
 
